From 563c4cf43e37be1f713f6533aa93fd216c1e9425 Mon Sep 17 00:00:00 2001
From: Chris Eppstein <chris@eppsteins.net>
Date: Wed, 21 Oct 2009 18:01:26 -0700
Subject: [PATCH] Slightly shorter is slightly better.

---
 features/command_line.feature                   | 8 ++++----
 features/step_definitions/command_line_steps.rb | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/features/command_line.feature b/features/command_line.feature
index bed6a532..e121fcb2 100644
--- a/features/command_line.feature
+++ b/features/command_line.feature
@@ -4,7 +4,7 @@ Feature: Command Line
   I want to create a new project
 
   Scenario: Install a project without a framework
-    When I enter the command: compass create my_project
+    When I run: compass create my_project
     Then a directory my_project/ is created
     And a configuration file my_project/config.rb is created
     And a sass file my_project/src/screen.sass is created
@@ -21,7 +21,7 @@ Feature: Command Line
     And I am told how to conditionally link "IE" to /stylesheets/ie.css for media "screen, projection"
 
   Scenario: Install a project with blueprint
-    When I enter the command: compass create bp_project --using blueprint
+    When I run: compass create bp_project --using blueprint
     Then a directory bp_project/ is created
     And a configuration file bp_project/config.rb is created
     And a sass file bp_project/src/screen.sass is created
@@ -39,7 +39,7 @@ Feature: Command Line
     And I am told how to conditionally link "lt IE 8" to /stylesheets/ie.css for media "screen, projection"
 
   Scenario: Install a project with specific directories
-    When I enter the command: compass create custom_project --using blueprint --sass-dir sass --css-dir css --images-dir assets/imgs
+    When I run: compass create custom_project --using blueprint --sass-dir sass --css-dir css --images-dir assets/imgs
     Then a directory custom_project/ is created
     And a directory custom_project/sass/ is created
     And a directory custom_project/css/ is created
@@ -49,7 +49,7 @@ Feature: Command Line
     And an image file custom_project/assets/imgs/grid.png is created
 
   Scenario: Perform a dry run of creating a project
-    When I enter the command: compass create my_project --dry-run
+    When I run: compass create my_project --dry-run
     Then a directory my_project/ is not created
     But a configuration file my_project/config.rb is reported created
     And a sass file my_project/src/screen.sass is reported created
diff --git a/features/step_definitions/command_line_steps.rb b/features/step_definitions/command_line_steps.rb
index 36f941a4..2d784a10 100644
--- a/features/step_definitions/command_line_steps.rb
+++ b/features/step_definitions/command_line_steps.rb
@@ -18,12 +18,12 @@ After do
   end
 end
 
-When /I enter the command: compass create ([^\s]+) ?(.+)?/ do |dir, args|
+When /I run: compass create ([^\s]+) ?(.+)?/ do |dir, args|
   @cleanup_directories << dir
   compass 'create', dir, *(args || '').split
 end
 
 # When /I enter the command: compass ([^\s]+) ?(.+)?/ do |command, args|
 #   compass command, *args.split
 # end
@@ -18,12 +18,12 @@ After do
 end
 
-# When /I enter the command: compass ([^\s]+) ?(.+)?/ do |command, args|
+# When /I run: compass ([^\s]+) ?(.+)?/ do |command, args|
 #   compass command, *args.split
 # end